MRatingItem class

Inheritance
Available extensions

Constructors

MRatingItem({Key? key, double rating = 4.5, TextStyle? textStyle, EdgeInsetsGeometry? padding, double size = 18.0, bool ignoreGestures = true, bool oneStar = true, required dynamic onRatingUpdate(double value), Color? color, EdgeInsetsGeometry? starPadding, IconData filledIcon = CupertinoIcons.star_fill, IconData emptyIcon = CupertinoIcons.star_fill, IconData halfIcon = CupertinoIcons.star_lefthalf_fill})
const

Properties

color Color?
final
emptyIcon IconData
final
filledIcon IconData
final
halfIcon IconData
final
hashCode int
The hash code for this object.
no setterinherited
ignoreGestures bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mCircular Widget

Available on Widget, provided by the WidgetController extension

no setter
mFlap Widget

Available on Widget, provided by the WidgetController extension

no setter
mNotStratch Widget

Available on Widget, provided by the WidgetController extension

no setter
mStretch Widget

Available on Widget, provided by the WidgetController extension

no setter
oneStar bool
final
onRatingUpdate → dynamic Function(double value)
final
padding EdgeInsetsGeometry?
final
rating double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final
starPadding EdgeInsetsGeometry?
final
textStyle TextStyle?
final

Methods

addAction({Function? onTap, Key? mKey, Function? onGesture, EdgeInsetsGeometry padding = EdgeInsets.zero, Alignment? alignment}) Widget

Available on Widget, provided by the WidgetController extension

addPadding({double all = 0.0, double horizontal = 0.0, double vertical = 0.0, double start = 0.0, double bottom = 0.0, double end = 0.0, double left = 0.0, double right = 0.0, double top = 0.0}) Widget

Available on Widget, provided by the SetPadding extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
mRadius(double radius) Widget

Available on Widget, provided by the WidgetController extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMaxWidth({required double width}) Widget

Available on Widget, provided by the WidgetController extension

setSize({required double width, required double height}) Widget

Available on Widget, provided by the WidgetController extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited